"use server";

import { requestGetFetch } from "@/utils/fetch";
import { Session } from "next-auth";
import { getServerSession } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { IbcProps } from "@/app/admin/settings/ibc/page";
import { SearchParams } from "@/types/searchParams";

export async function getAssignPriorityRequestList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const paramsArray = searchParams && Object.entries(searchParams);

    const queryString = paramsArray && paramsArray.map(([key, value]) => `${key}=${value}`).join('&');

    const path = 'v1/assignment-priorities' + `${queryString ? `?${queryString}` : ''}`;


    const response = await requestGetFetch({
      path: path.toString(),
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}


export async function editAssignPriorityRequest(payload: { userId: string; data: any }) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/assignment-priorities/" + payload?.userId;
    const response = await requestGetFetch({
      path,
      options: {
        method: "PUT",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify(payload?.data || {}),
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}


export async function createAssignPriorityRequest(payload: any) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    const path = "v1/assignment-priorities";
    const response = await requestGetFetch({
      path,
      options: {
        method: "POST",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
        body: JSON.stringify({ ...payload }),
      },
    });

    return response
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}


export async function deleteAssignPriority(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/assignment-priorities/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Delete",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {
    }
    throw error;
  }
}
